package com.install4j.api.beans;

import java.awt.*;
import java.io.Serializable;

/**
 * Property type for an anchor.
 *
 * @author ej-technologies GmbH
 */

public class Anchor implements Serializable {

    public static final Anchor NORTHWEST = new Anchor("North-West", GridBagConstraints.NORTHWEST);
    public static final Anchor NORTH = new Anchor("North", GridBagConstraints.NORTH);
    public static final Anchor NORTHEAST = new Anchor("North-East", GridBagConstraints.NORTHEAST);
    public static final Anchor WEST = new Anchor("West", GridBagConstraints.WEST);
    public static final Anchor CENTER = new Anchor("Center", GridBagConstraints.CENTER);
    public static final Anchor EAST = new Anchor("East", GridBagConstraints.EAST);
    public static final Anchor SOUTHWEST = new Anchor("South-West", GridBagConstraints.SOUTHWEST);
    public static final Anchor SOUTH = new Anchor("South", GridBagConstraints.SOUTH);
    public static final Anchor SOUTHEAST = new Anchor("South-East", GridBagConstraints.SOUTHEAST);

    private static final Anchor[] VALUES = new Anchor[] {
        NORTHWEST,
        NORTH,
        NORTHEAST,
        WEST,
        CENTER,
        EAST,
        SOUTHWEST,
        SOUTH,
        SOUTHEAST
    };

    private String verbose;
    private final int value;

    /**
     * Get the anchor constant that corresponds to the specified value
     * @param value the value, as returned by {@link #getValue()}
     * @see #getValue()
     * @return the anchor or <tt>null</tt> if the value cannot be found
     */
    public static Anchor getByValue(int value) {
        for (int i = 0; i < VALUES.length; i++) {
            Anchor anchor = VALUES[i];
            if (anchor.getValue() == value) {
                return anchor;
            }
        }
        return null;
    }

    private Anchor(String verbose, int value) {
        this.verbose = verbose;
        this.value = value;
    }

    /**
     * The value of the anchor which can be used by <tt>java.awt.GridBagLayout</tt>.
     * @return the value, one of the anchor constants in <tt>java.awt.GridBagConstraints</tt>
     */
    public int getValue() {
        return value;
    }

    public String toString() {
        return verbose;
    }

}
