package com.install4j.api.beans;

import java.util.HashMap;
import java.util.Map;

/**
 * Container for a set of localized files that represent a single {@link ExternalFile} with textual content.
 * If you want the user to be able to specify localized versions of a text file for a single property,
 * you can declare the property to be of type <tt>LocalizedExternalFile</tt>. Important:
 * you have to initialize the field with an instance rather than leave it to be <tt>null</tt>.
 * <p>In the install4j IDE, the user will be presented with a dialog that allows file selection for all
 * installer languages that are configured on the General Settings->Languages tab. At runtime, call
 * {@link com.install4j.api.context.Context#getExternalFile(LocalizedExternalFile, boolean)} to
 * get the actual file for further use in your bean implementation.
 * <p>In your bean info, use the {@link com.install4j.api.beaninfo.FilePropertyDescriptor} class to
 * register the property. All attributes of <tt>FilePropertyDescriptor</tt> are supported
 * for <tt>LocalizedExternalFile</tt>.
 *
 * @see ExternalFile
 * @author ej-technologies GmbH
 */
public class LocalizedExternalFile {

    private Map languageIdToExternalFile = new HashMap();

    /**
     * Returns the map from language IDs to {@link ExternalFile}s. You do not
     * have to use this method, a more convenient way to retrieve the actual file at
     * runtime is to call {@link com.install4j.api.context.Context#getExternalFile(LocalizedExternalFile, boolean)}.
     * @return the map
     */
    public Map getLanguageIdToExternalFile() {
        return languageIdToExternalFile;
    }

    /**
     * Sets the map from language IDs to {@link ExternalFile}s. This method is called by
     * the install4j IDE.
     * @param languageIdToExternalFile the map
     */
    public void setLanguageIdToExternalFile(Map languageIdToExternalFile) {
        this.languageIdToExternalFile = languageIdToExternalFile;
    }

}
